<?php
namespace Teknisa\GOP\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Gop11000AprovaOrcaOperacController extends \Teknisa\GER\Controllers\TeknisaCrud{
    protected $dataSourceName = "gop11_teste";
    protected $dataSourceManager;
    protected $connection;
    protected $newCode;
    protected $environment;

    
    public function __construct($crudService, ParameterBag $parameterBag, $dataSourceManager, $connection, $newCode, $environment) {
        $this->dataSourceManager    = $dataSourceManager;
        $this->connection = $connection;
        $this->newCode = $newCode;
        $this->environment = $environment;
        parent::__construct($crudService, $parameterBag);
    }
    
    
    
    public function saveAprova(DTO\Request $request, DTO\Response $response ){
        $dados = $request->getDataSet();
        if(!empty($dados)){
                $rows = $dados->getRows();
                
           if(!empty($rows)){     
                $aprovados = $rows[0];
                $parametros =  array(
                    'P_NRORCAMENTOGOP' => $aprovados["NRORCAMENTOGOP"],
                    'P_NRAPROVAORCAGOP' => $this->newCode->getCodeByTableName("APROVAORCAGOP", $this->environment->getNrorg()),
                    'P_CDOPERADOR' => $this->environment->getCdOperador(),
                    'P_IDAPROVACAOGOP' => $aprovados["IDAPROVACAOGOP"],
                    'P_DSOBSERVACAO' => $aprovados["DSOBSERVACAO"],
                    'P_NRORG' => $this->environment->getNrorg(),
                    'P_DTINCLUSAO' => $this->crudService->getEnvironment()->getCurrentTime()->format("d/m/Y H:i:s"),
                    'P_NRORGINCLUSAO' => $this->environment->getNrorg(),
                    'P_CDOPERINCLUSAO' => $this->environment->getCdOperador()
                );
                 $stmt = $this->connection->prepare("
                     INSERT INTO
                        APROVAORCAGOP 
                    (
                        NRORCAMENTOGOP,
                        NRAPROVAORCAGOP,
                        CDOPERADOR,
                        IDAPROVACAOGOP,
                        DSOBSERVACAO,
                        NRORG,
                        DTINCLUSAO,
                        NRORGINCLUSAO,
                        CDOPERINCLUSAO
                     ) 
                    VALUES(
                        :P_NRORCAMENTOGOP,
                        :P_NRAPROVAORCAGOP,
                        :P_CDOPERADOR,
                        :P_IDAPROVACAOGOP,
                        :P_DSOBSERVACAO,
                        :P_NRORG,
                        :P_DTINCLUSAO,
                        :P_NRORGINCLUSAO,
                        :P_CDOPERINCLUSAO
                    )"); 
                try{
                    $stmt->execute($parametros);
                    $retorno = '';
                    $procedure = new StoredProcedure($this->connection, 'CONSISTE_ORCAMENTO_GOP');

                    $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $aprovados['CDFILIAL'],   Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, null,                     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_NRDEMANDA', Param::PARAM_INPUT, null,                     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_RETORNO',   Param::PARAM_OUTPUT,$retorno,                 Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_NRORG',     Param::PARAM_INPUT, $this->environment->getNrorg(), Param::PARAM_TYPE_STR));
    
                    $procedure->execute();
                }catch(\Exception $ex){
                    $response->setError(new Error($ex->getMessage(), 500));
                }
            } 
        }
    }
    
    public function updateAprova(DTO\Request $request, DTO\Response $response ){
        $dados = $request->getDataSet();
        if(!empty($dados)){
                $rows = $dados->getRows();
           if(!empty($rows)){     
                $aprovados = $rows[0];
                $parametros =  array(
                    'P_NRAPROVAORCAGOP' => $aprovados["NRAPROVAORCAGOP"],
                    'IDAPROVACAOGOP' => $aprovados["IDAPROVACAOGOP"],
                    'DSOBSERVACAO' => $aprovados["DSOBSERVACAO"],
                    'DTULTATU' => $this->crudService->getEnvironment()->getCurrentTime()->format("d/m/Y H:i:s"),
                    'NRORGULTATU' => $this->environment->getNrorg(),
                    'CDOPERULTATU' => $this->environment->getCdOperador()
                );
                 $stmt = $this->connection->prepare("
                 UPDATE APROVAORCAGOP
                    SET IDAPROVACAOGOP = :IDAPROVACAOGOP,
                        DSOBSERVACAO = :DSOBSERVACAO,
                        DTULTATU = :DTULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        CDOPERULTATU = :CDOPERULTATU
                  WHERE NRAPROVAORCAGOP = :P_NRAPROVAORCAGOP");
                try{
                    $stmt->execute($parametros);
                    $retorno = '';
                    $procedure = new StoredProcedure($this->connection, 'CONSISTE_ORCAMENTO_GOP');

                    $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $aprovados['CDFILIAL'],   Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, null,                     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_NRDEMANDA', Param::PARAM_INPUT, null,                     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_RETORNO',   Param::PARAM_OUTPUT,$retorno,                 Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_NRORG',     Param::PARAM_INPUT, $this->environment->getNrorg(), Param::PARAM_TYPE_STR));
    
                    $procedure->execute();
                }catch(\Exception $ex){
                    $response->setError(new Error($ex->getMessage(), 500));
                }
            } 
        }
    }

    public function updateConclusao(DTO\Request $request, DTO\Response $response ){
        $dados = $request->getDataSet();
        if(!empty($dados)){
           $rows = $dados->getRows();
           if(!empty($rows)){     
                $aprovados = $rows[0];
                
                $parametros = array(
                    'IDSTATUS' => $aprovados["IDSTATUS"],
                    'DSOBSERVACAO' => $aprovados["DSOBSERVACAO"],
                    'CDFILIAL' => $aprovados["CDFILIAL"],
                    'P_NRCONCPREORCAGOP' => $aprovados["NRCONCPREORCAGOP"]
                );
                $stmt = $this->connection->prepare("
                    UPDATE CONCPREORCAGOP
                       SET IDSTATUS = :IDSTATUS,
                           DSOBSERVACAO = :DSOBSERVACAO
                     WHERE CDFILIAL = :CDFILIAL
                       AND NRCONCPREORCAGOP = :P_NRCONCPREORCAGOP");
                try{
                    $stmt->execute($parametros);
                }catch(\Exception $ex){
                    $response->setError(new Error("Nao foi possivel processar os dados enviados   --- " . $ex->getMessage(), 500));
                }
            } 
        }
    }

}

